package rs.ac.bg.fon.ai.inteligentniSistemi.rdf;

import org.apache.jena.rdf.model.Model;
import org.apache.jena.rdf.model.ModelFactory;
import org.apache.jena.rdf.model.Property;
import org.apache.jena.rdf.model.RDFNode;
import org.apache.jena.rdf.model.Resource;
import org.apache.jena.rdf.model.Statement;
import org.apache.jena.rdf.model.StmtIterator;
import org.apache.jena.vocabulary.RDFS;

public class Example1 {
	
	private static final String EXAMPLE_NS = "http://example-vocab.com/";
	
	public static void main(String[] args) {
		
		//creating empty model (RDF graph)
		Model rdfGraph = ModelFactory.createDefaultModel();
		
		// set the namespace (and its prefix) to be used for naming the graph elements
		rdfGraph.setNsPrefix("ex", EXAMPLE_NS);
		
		// create data model
		
		//create classes
		Resource movieCls = rdfGraph.createResource(EXAMPLE_NS + "Movie", RDFS.Class);
		Resource personCls = rdfGraph.createResource(EXAMPLE_NS + "Person", RDFS.Class);
		
		// create properties
		Property directorProp = rdfGraph.createProperty(EXAMPLE_NS, "director");
		Property titleProp = rdfGraph.createProperty(EXAMPLE_NS, "title");
		Property nameProp = rdfGraph.createProperty(EXAMPLE_NS, "name");
		
		//create instances
		Resource cNolanInst = rdfGraph.createResource("http://dbpedia.org/resource/Christopher_Nolan", personCls);
		cNolanInst.addProperty(nameProp, "Christopher Nolan");
		
		Resource interstellarInst = rdfGraph.createResource("http://dbpedia.org/resource/Interstellar_(film)", movieCls);
		interstellarInst.addProperty(titleProp, "Interstellar");
		interstellarInst.addProperty(directorProp, cNolanInst);
		
		// print the graph using JSON-LD syntax
		rdfGraph.write(System.out, "JSON-LD");
		
		// iterate through the statements and print them
		System.out.println("\n\nRDF statements:\n");
		StmtIterator stmtIter = rdfGraph.listStatements();
		while (stmtIter.hasNext()) {
			Statement statement = (Statement) stmtIter.next();
			
			Resource subject = statement.getSubject();
			Property predicate = statement.getPredicate();
			RDFNode object = statement.getObject();
			
			System.out.print(subject.getURI() + " -- " + predicate.getURI() + " -- ");
			if ( object.isLiteral() )
				System.out.println("\"" + object.asLiteral().getLexicalForm() + "\".");
			else
				System.out.println(object.asResource().getURI() + ".");
			
		}
	}

}
