package rs.ac.bg.fon.ai.inteligentniSistemi.rdf;

import org.apache.jena.rdf.model.Model;
import org.apache.jena.rdf.model.ModelFactory;
import org.apache.jena.rdf.model.Property;
import org.apache.jena.rdf.model.Resource;
import org.apache.jena.vocabulary.RDFS;
import org.apache.jena.vocabulary.XSD;

public class Example2 {
	
	private static final String EXAMPLE_NS = "http://example-vocab.com/";

	public static void main(String[] args) {
		
		// create (empty) graph
		Model rdfGraph = ModelFactory.createDefaultModel();
		
		// add namespace prefix
		rdfGraph.setNsPrefix("ex", EXAMPLE_NS);
		
		// add classes
		
		// Event class
		Resource eventCls = rdfGraph.createResource(EXAMPLE_NS + "Event", RDFS.Class);
		// Film festival class
		Resource filmFestCls = rdfGraph.createResource(EXAMPLE_NS + "FilmFestival", RDFS.Class);
		filmFestCls.addProperty(RDFS.subClassOf, eventCls);
		// Film class
		Resource filmCls = rdfGraph.createResource(EXAMPLE_NS + "Film", RDFS.Class);
		// Documentary class
		Resource documentaryCls = rdfGraph.createResource(EXAMPLE_NS + "Documentary", RDFS.Class);
		documentaryCls.addProperty(RDFS.subClassOf, filmCls);
		
		// add properties, including domain and range for each property
		
		// note that we are using name property to assign name to both film festival and films
		// so, we keep its domain undefined
		Property nameProp = rdfGraph.createProperty(EXAMPLE_NS, "name");
		nameProp.addProperty(RDFS.range, XSD.xstring);
		
		Property locationProp = rdfGraph.createProperty(EXAMPLE_NS, "location");
		locationProp.addProperty(RDFS.range, XSD.xstring);
		locationProp.addProperty(RDFS.domain, eventCls);
		
		Property startDateProp = rdfGraph.createProperty(EXAMPLE_NS, "startDate");
		startDateProp.addProperty(RDFS.range, XSD.dateTime);
		startDateProp.addProperty(RDFS.domain, filmFestCls);
		
		Property endDateProp = rdfGraph.createProperty(EXAMPLE_NS, "endDate");
		endDateProp.addProperty(RDFS.range, XSD.dateTime);
		endDateProp.addProperty(RDFS.domain, filmFestCls);
		
		Property screenedProp = rdfGraph.createProperty(EXAMPLE_NS, "screenedAt");
		screenedProp.addProperty(RDFS.domain, filmCls);
		screenedProp.addProperty(RDFS.range, filmFestCls);
		
		Property lengthProp = rdfGraph.createProperty(EXAMPLE_NS, "length");
		lengthProp.addProperty(RDFS.domain, filmCls);
		lengthProp.addProperty(RDFS.range, XSD.xstring);
		
		Property directorProp = rdfGraph.createProperty(EXAMPLE_NS, "directedBy");
		directorProp.addProperty(RDFS.domain, filmCls);
		directorProp.addProperty(RDFS.range, XSD.xstring);
		
		// add instances
		
		// Film festival instance
		Resource freeZoneInst = rdfGraph.createResource("http://freezonebelgrade.org/", filmFestCls);
		freeZoneInst.addLiteral(nameProp, "FreeZone2016");
		freeZoneInst.addLiteral(locationProp, "Belgrade, Serbia");
		freeZoneInst.addProperty(startDateProp, "2016-11-10T00:01");
		freeZoneInst.addProperty(endDateProp, "2016-11-15T23:59");
		
		// Documentary instance
		Resource demainInst = rdfGraph.createResource("http://www.demain-lefilm.com/", documentaryCls);
		demainInst.addProperty(nameProp, "Tomorrow", "en");
		demainInst.addProperty(lengthProp, "118min");
		demainInst.addProperty(directorProp, "Malani Loren");
		demainInst.addProperty(directorProp, "Siril Dion");
		demainInst.addProperty(screenedProp, freeZoneInst);
		
		// print
		rdfGraph.write(System.out, "JSON-LD");
		
	}

}
